Generate text-centric icons for your Mac OS X dock.

Examples:

![Edge icon](https://github.com/pamelafox/dock-icons/raw/main//examples/edge.png?raw)

![VS Code icon](https://github.com/pamelafox/dock-icons/raw/main//examples/vscode.png?raw)

![Teams icon](https://github.com/pamelafox/dock-icons/raw/main//examples/teams.png?raw)
